# Pull Request

## 📝 Summary

<!-- Provide a brief, high-level description of the changes in this PR. -->

## ✅ Pre-submission Checklist

- [ ] I have searched existing issues and pull requests to ensure this change is not a duplicate.
- [ ] I have read and followed the [**Contributing Guidelines**](docs/project/CONTRIBUTING.md).
- [ ] I have tested my changes locally and they work as expected.
- [ ] I have added or updated tests to cover my changes.
- [ ] I have updated the documentation to reflect my changes.

## 🎯 Type of Change

- [ ] 🐛 Bug fix (non-breaking change that fixes an issue)
- [ ] ✨ New feature (non-breaking change that adds functionality)
- [ ] 💥 Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] 📚 Documentation update
- [ ] ⚡ Performance improvement
- [ ] 🔧 Code refactoring
- [ ] 🧪 Test improvement

## 🚀 What's New?

<!--
Provide a concise summary of the new features, improvements, or bug fixes.
This will be used to generate release notes.
-->

## 💡 Motivation and Context

<!--
Why is this change required? What problem does it solve?
If it fixes an open issue, please link to the issue here.
-->

Fixes #<!-- issue number -->

## 🛠️ How Has This Been Tested?

<!--
Please describe the tests that you ran to verify your changes.
Provide instructions so we can reproduce.
-->

- [ ] Unit tests
- [ ] Integration tests
- [ ] Manual tests on the following platforms:
    - [ ] macOS (Apple Silicon)
    - [ ] macOS (Intel)
    - [ ] Linux (x86)
    - [ ] Windows

## 📸 Screenshots (if appropriate)

<!-- If your change includes any UI changes, please provide screenshots. -->

## 📦 Any new dependencies?

<!-- List any new dependencies that this PR introduces. -->
